@@ -21,8 +21,10 @@ class LoadDataKline:
 
     def load_all(self, *args, **kwargs):
         self.exchange.load_markets()
-        for sym in tqdm(self.exchange.symbols):
+        pbr = tqdm(self.exchange.symbols)
+        for sym in pbr:
             if ':' not in sym:
+                pbr.set_description(sym)
                 self.load(sym, *args, **kwargs)
 
     def _load(self, symbol, fetch_since, timeframe='1m', limit=100, try_times=3, *args, **kwargs):
@@ -97,8 +99,10 @@ class LoadTradeKline:
 
     def load_all(self, *args, **kwargs):
         self.exchange.load_markets()
-        for sym in tqdm(self.exchange.symbols):
+        pbr = tqdm(self.exchange.symbols)
+        for sym in pbr:
             if ':' not in sym:
+                pbr.set_description(sym)
                 self.load(sym, *args, **kwargs)
 
     def load(self, symbol, unix_start, unix_end, *args, **kwargs):
